<?php

namespace Controller;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Service\CpAssinaturaDigitalService;
use Zeedhi\Framework\DTO\Row;
use Zeedhi\Framework\HTTP\Kernel;

class CpAssinaturaDigitalController {

    protected $cpAsssinaDigitalservice;
    protected $httpKernel;

    public function __construct(CpAssinaturaDigitalService $cpAsssinaDigitalservice, Kernel $httpKernel){
        $this->cpAssinaDigitalservice = $cpAsssinaDigitalservice;
        $this->httpKernel = $httpKernel;
    }

    public function uploadtoCertsing(Request $request, Response $response){
        try {

             $upload = $this->cpAssinaDigitalservice->uploadtoCertsing();

             $response->addDataSet(new DataSet("RESULT", $upload));

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }


    public function createSignatureCertsing(Request $request, Response $response){
        try {

            $create = $this->cpAssinaDigitalservice->createSignatureCertsing();

            $response->addDataSet(new DataSet("RESULT", $create));

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    
    public function callbackCertsing(Request $request, Response $response){
        try {
            $parametros = $request->getParameters();
            $nrorg = $this->httpKernel->getHttpRequest()->getHeaders()->get("nrorg");

            $dadosIntegracao = $parametros["dataset"][0];
            
            $this->cpAssinaDigitalservice->callbackCertsing($dadosIntegracao, $nrorg);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    public function incluirSignatario(Request $request, Response $response){
        try {
            
            $this->cpAssinaDigitalservice->incluirSignatario($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    public function excluirSignatario(Request $request, Response $response){
        try {
            
            $this->cpAssinaDigitalservice->excluirSignatario($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    
    public function reenviarSolicitacao(Request $request, Response $response){
        try {
            
            $this->cpAssinaDigitalservice->reenviarSolicitacao($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    public function excluirdocumento(Request $request, Response $response){
        try {
            $this->cpAssinaDigitalservice->excluirdocumento($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}